@@ -4,12 +4,12 @@ use Moo;
 
 use namespace::autoclean;
 
-our $VERSION = '0.000027';
+our $VERSION = '0.000028';
 
-use Data::GUID;
-use DateTime;
-use DateTime::Format::MySQL;
-use DateTime::TimeZone;
+use Data::GUID              ();
+use DateTime                ();
+use DateTime::Format::MySQL ();
+use DateTime::TimeZone      ();
 use Types::Standard qw( InstanceOf );
 
 has _time_zone => (
@@ -73,7 +73,7 @@ WebService::PayPal::PaymentsAdvanced::Mocker::Helper - Helper methods used when
 
 =head1 VERSION
 
-version 0.000027
+version 0.000028
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by MaxMind, Inc.
+This software is copyright (c) 2022 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
