@@ -4,13 +4,13 @@ use Moo;
 
 use namespace::autoclean;
 
-our $VERSION = '0.000027';
+our $VERSION = '0.000028';
 
 use List::AllUtils qw( any );
 use Types::Common::String qw( NonEmptyStr );
 use Types::Standard qw( ArrayRef Int Maybe );
-use WebService::PayPal::PaymentsAdvanced::Error::Authentication;
-use WebService::PayPal::PaymentsAdvanced::Error::Generic;
+use WebService::PayPal::PaymentsAdvanced::Error::Authentication ();
+use WebService::PayPal::PaymentsAdvanced::Error::Generic        ();
 
 has _nonfatal_result_codes => (
     init_arg => 'nonfatal_result_codes',
@@ -72,7 +72,7 @@ WebService::PayPal::PaymentsAdvanced::Response - Generic response object
 
 =head1 VERSION
 
-version 0.000027
+version 0.000028
 
 =head1 SYNOPSIS
 
@@ -121,7 +121,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by MaxMind, Inc.
+This software is copyright (c) 2022 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
