@@ -4,12 +4,12 @@ use Moo::Role;
 
 use namespace::autoclean;
 
-our $VERSION = '0.000027';
+our $VERSION = '0.000028';
 
 use feature qw( state );
 
-use DateTime::TimeZone;
-use DateTime::Format::MySQL;
+use DateTime::TimeZone      ();
+use DateTime::Format::MySQL ();
 use Types::Standard qw( InstanceOf Maybe );
 
 has transaction_time => (
@@ -41,7 +41,7 @@ WebService::PayPal::PaymentsAdvanced::Role::HasTransactionTime - Role which conv
 
 =head1 VERSION
 
-version 0.000027
+version 0.000028
 
 =head2 transaction_time
 
@@ -57,7 +57,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by MaxMind, Inc.
+This software is copyright (c) 2022 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
